@@ -15,10 +15,22 @@ program fft_test
   real, allocatable :: ren(:)
   real :: tf1, tf2, to1, to2, err_max
   integer :: i, emax
+  character(1) :: flag
+  integer, dimension(5) :: prim
 
-  write(*,*) "input the data number (odd number)."
+  write(*,*) "Input the data number (odd number)."
   read(*,*) n
 
+!  write(*,*) "Do calculate the prime factors? [y/n]"
+!  read(*,*) flag
+
+!  if(flag=='n')then
+!     write(*,*) "Input each prime factor (2,3,5,7,other)."
+!     read(*,*) prim(1), prim(2), prim(3), prim(4), prim(5)
+!  end if
+
+  flag=""
+
   allocate(re(n))
   allocate(co(n/2))
   allocate(ren(n))
@@ -30,8 +42,13 @@ program fft_test
 
   call cpu_time( tf1 )
 
-  call r2c_ffttp_1d( n, re, co, prim='o' )
-  call c2r_ffttp_1d( n, co, ren, prim='o' )
+  if(flag=='y')then
+     call r2c_ffttp_1d( n, re, co, prim='o' )
+     call c2r_ffttp_1d( n, co, ren, prim='o' )
+  else
+     call r2c_ffttp_1d( n, re, co, prim='o', prim_fact=prim )
+     call c2r_ffttp_1d( n, co, ren, prim='o', prim_fact=prim )
+  end if
 
   call cpu_time( tf2 )
 
@@ -45,8 +62,13 @@ program fft_test
 
   call cpu_time( to1 )
 
-  call r2c_ffttp_1d( n, re, co, prim='x' )
-  call c2r_ffttp_1d( n, co, ren, prim='x' )
+  if(flag=='y')then
+     call r2c_ffttp_1d( n, re, co, prim='x' )
+     call c2r_ffttp_1d( n, co, ren, prim='x' )
+  else
+     call r2c_ffttp_1d( n, re, co, prim='x', prim_fact=prim )
+     call c2r_ffttp_1d( n, co, ren, prim='x', prim_fact=prim )
+  end if
 
   call cpu_time( to2 )
 
