@@ -530,7 +530,6 @@ subroutine interpolation_1d( x, y, point, val )
   fd=(xmax-xmin)/(tmax-tmin)
 
   val=xmin+dt*fd
-
 end subroutine interpolation_1d
 
 
@@ -580,7 +579,139 @@ subroutine interpolation_3d( x, y, z, u, point, val )
 
 end subroutine interpolation_3d
 
+!------------------------------------
+!------------------------------------
 
+subroutine auto_interpolation_1d( x, r, u, v, undef )
+  ! ɸ x Ƥǡ u 
+  ! ɸ r ǡ v ˼ưޤ.
+  implicit none
+  real, intent(in) :: x(:)  ! ɸ
+  real, intent(in) :: r(:)  ! ޺ɸ
+  real, intent(in) :: u(size(x))  ! ǡ
+  real, intent(inout) :: v(size(r))  ! ޤǡ
+  integer, intent(in), optional :: undef  ! ̤
+  integer :: i, nx, nr, ix, ir
+  integer :: defun
+
+  if(present(undef))then
+     defun=undef
+  else
+     defun=0
+  end if
+
+  nx=size(x)
+  nr=size(r)
+
+  do i=1, nr
+     call interpo_search_1d( x, r(i), ir, defun )
+
+     if(ir/=defun.and.ir<nx)then
+        call interpolation_1d( x(ir:ir+1), u(ir:ir+1), r(i), v(i) )
+     else
+        v(i)=real(defun)
+     end if
+  end do
+
+end subroutine auto_interpolation_1d
+
+!------------------------------------
+!------------------------------------
+
+subroutine auto_interpolation_2d( x, y, r, q, u, v, undef )
+  ! ɸ x, y Ƥǡ u 
+  ! ɸ r, q ǡ v ˼ưޤ.
+  implicit none
+  real, intent(in) :: x(:)  ! ɸ 1
+  real, intent(in) :: y(:)  ! ɸ 2
+  real, intent(in) :: r(:)  ! ޺ɸ 1
+  real, intent(in) :: q(:)  ! ޺ɸ 2
+  real, intent(in) :: u(size(x),size(y))  ! ǡ
+  real, intent(inout) :: v(size(r),size(q))  ! ޤǡ
+  integer, intent(in), optional :: undef  ! ̤
+  integer :: i, j, nx, ny, nr, nq, ix, iy, ir, iq
+  integer :: defun
+
+  if(present(undef))then
+     defun=undef
+  else
+     defun=0
+  end if
+
+  nx=size(x)
+  ny=size(y)
+  nr=size(r)
+  nq=size(q)
+
+  do j=1, nq
+     do i=1, nr
+        call interpo_search_2d( x, y, r(i), q(j), ir, iq, defun )
+
+        if(ir/=defun.and.iq/=defun.and.ir<nx.and.iq<ny)then
+           call interpolation_2d( x(ir:ir+1), y(iq:iq+1),  &
+  &                               u(ir:ir+1,iq:iq+1), (/r(i), q(j)/), v(i,j) )
+        else
+           v(i,j)=real(defun)
+        end if
+     end do
+  end do
+
+end subroutine auto_interpolation_2d
+
+!------------------------------------
+!------------------------------------
+
+subroutine auto_interpolation_3d( x, y, z, r, q, p, u, v, undef )
+  ! ɸ x, y, z Ƥǡ u 
+  ! ɸ r, q, p ǡ v ˼ưޤ.
+  implicit none
+  real, intent(in) :: x(:)  ! ɸ 1
+  real, intent(in) :: y(:)  ! ɸ 2
+  real, intent(in) :: z(:)  ! ɸ 3
+  real, intent(in) :: r(:)  ! ޺ɸ 1
+  real, intent(in) :: q(:)  ! ޺ɸ 2
+  real, intent(in) :: p(:)  ! ޺ɸ 3
+  real, intent(in) :: u(size(x),size(y),size(z))  ! ǡ
+  real, intent(inout) :: v(size(r),size(q),size(p))  ! ޤǡ
+  integer, intent(in), optional :: undef  ! ̤
+  integer :: i, j, k, nx, ny, nz, nr, nq, np, ix, iy, iz, ir, iq, ip
+  integer :: defun
+
+  if(present(undef))then
+     defun=undef
+  else
+     defun=0
+  end if
+
+  nx=size(x)
+  ny=size(y)
+  nz=size(z)
+  nr=size(r)
+  nq=size(q)
+  np=size(p)
+
+  do k=1, np
+     do j=1, nq
+        do i=1, nr
+           call interpo_search_3d( x, y, z, r(i), q(j), p(k),  &
+  &                                ir, iq, ip, defun )
+
+           if(ir/=defun.and.iq/=defun.and.ip/=defun.and.  &
+  &           ir<nx.and.iq<ny.and.ip<nz)then
+              call interpolation_3d( x(ir:ir+1), y(iq:iq+1), z(ip:ip+1),  &
+  &                               u(ir:ir+1,iq:iq+1,ip:ip+1),  &
+  &                               (/r(i), q(j), p(k)/), v(i,j,k) )
+           else
+              v(i,j,k)=real(defun)
+           end if
+        end do
+     end do
+  end do
+
+end subroutine auto_interpolation_3d
+
+!------------------------------------
+!------------------------------------
 
 subroutine LSM( x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻
   implicit none
@@ -617,6 +748,7 @@ subroutine LSM( x, y, slope, intercept, undef )  ! Ǿˡˤ뷹ҷ׻
 
 end subroutine LSM
 
+!------------------------------------
 !------------------------------------
 
 subroutine LSM_poly( x, y, a, intercept, undef )
