@@ -27,6 +27,42 @@ end function
 !-----------------------------------------------------
 !-----------------------------------------------------
 
+real function goff_gratch(T)  ! goff-gratch μѤ˰¿׻.
+  use Thermo_Const
+  implicit none
+  real, intent(in) :: T  ! 絤β [K]
+  real, parameter :: a=-7.90298, b=5.02808, c=-1.3816e-7, d=8.1328e-3
+  real, parameter :: pa=11.344, pb=-3.49149
+  real, parameter :: tst=373.15
+  real, parameter :: est=1.01325e5
+  real :: term
+
+  term=a*(tst/T-1.0)+b*log10(tst/T)+c*(10.0**(pa*(1.0-T/tst))-1.0)+d*(10.0**(pb*(tst/T-1.0))-1.0)
+  goff_gratch=est*10.0**(term)
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
+real function goff_gratch_i(T)  ! goff-gratch μѤ˰¿ (ɹ˰) ׻.
+  use Thermo_Const
+  implicit none
+  real, intent(in) :: T  ! 絤β [K]
+  real, parameter :: a=-9.09718, b=-3.56654, c=0.876793
+  real, parameter :: est=6.1173e2
+  real :: term
+
+  term=a*(ti0/T-1.0)+b*log10(ti0/T)+c*(1.0-t/ti0)
+  goff_gratch_i=ei0*10.0**(term)
+
+  return
+end function
+
+!-----------------------------------------------------
+!-----------------------------------------------------
+
 real function es_Bolton(T)  ! Bolton(1980) μˡѤ˰¿׻.
   use Thermo_Const
   implicit none
@@ -48,7 +84,11 @@ real function es_TD(e)  ! es_Bolton Ѥ˰¿η׻εջ
   real, intent(in) :: e  ! 絤ο [Pa]
   real, parameter :: a=17.67, c=29.65
 
-  es_TD=c+(a*(t0-c))/(a-log(e/e0))
+  if(e>0.0)then
+     es_TD=c+(a*(t0-c))/(a-log(e/e0))
+  else
+     es_TD=t0  ! true ??
+  end if
 
   return
 end function
@@ -99,7 +139,7 @@ real function TP_2_qvs(T,P)  ! ٤˰º׻
   real, intent(in) :: T  !  [K]
   real, intent(in) :: P  ! 絤 [Pa]
   real :: eps
-  real :: eP_2_qv, es
+  real :: es
 
   eps=Rd/Rv
   es=es_Bolton(T)
@@ -212,7 +252,11 @@ real function TqvP_2_TLCL(T,qv,P)  !! ٤Ⱥ T_LCL ׻
 
   e=qvP_2_e(qv,P)
   e=e*1.0e-2
-  TqvP_2_TLCL=coe/(a*log(T)-log(e)-b)+55.0
+  if(e>0.0)then
+     TqvP_2_TLCL=coe/(a*log(T)-log(e)-b)+55.0
+  else
+     TqvP_2_TLCL=coe/(a*log(T)-b)+55.0  ! true ??
+  end if
 
   return
 end function
@@ -364,7 +408,7 @@ real function qvTP_2_RH(qv,T,P)  ! Ȳ٤м٤׻.
   real, intent(in) :: qv  ! м [kg / kg]
   real, intent(in) :: T  !  [K]
   real, intent(in) :: P  !  [Pa]
-  real :: e, es
+  real :: e
 
   e=qvP_2_e(qv,P)
   qvTP_2_RH=eT_2_RH(e,T)
@@ -382,7 +426,7 @@ real function exner_func_dry(P)  ! 絤ˤĤƤΥʡؿ׻
   real :: kappa
 
   kappa=Rd/Cpd
-  exner_func_dry=(p0/P)**kappa
+  exner_func_dry=(P/p0)**kappa
 
   return
 end function
@@ -487,23 +531,27 @@ real function moist_laps_temp( p_stan, T_stan, p )
   real, intent(in) :: T_stan  ! ಹ [K]
   real, intent(in) :: p  ! ٤ˤ뵤 [Pa]
   real :: seqpt, t_temp, seqpt_temp, dt, seqpt_temp2
-  integer :: i, j, k
   integer, parameter :: ilim=20
   real, parameter :: limit=2.0e-4
 
   seqpt=thetaes_Bolton( T_stan, p_stan )
   seqpt_temp=thetaes_Bolton( t_stan, p )
-  dt=1.0
-  t_temp=t_stan-dt
+  if(p>p_stan)then
+     dt=1.0
+  else
+     dt=-1.0
+  end if
+  t_temp=t_stan+dt
   seqpt_temp2=thetaes_Bolton( t_temp, p )
 
-  do while ( (seqpt_temp2-seqpt)*(seqpt_temp-seqpt) >0 )
-     t_temp=t_temp-dt
+  do while ( (seqpt_temp2-seqpt)*(seqpt_temp-seqpt) >0.0 )
+     t_temp=t_temp+dt
      seqpt_temp=seqpt_temp2
      seqpt_temp2=thetaes_Bolton( t_temp, p )
   end do
 
   seqpt_temp=seqpt_temp2
+  dt=1.0
 
   do while ( abs(seqpt_temp-seqpt) > limit )
 
